@@ -1,5 +1,5 @@
 package Crypt::HSM::Session;
-$Crypt::HSM::Session::VERSION = '0.001';
+$Crypt::HSM::Session::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -22,11 +22,11 @@ Crypt::HSM::Session - A PKCS11 session
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
- $session->encrypt('aes-cbc', $key, $plaintext);
+ $session->encrypt('aes-cbc', $key, $plaintext, $iv);
 
  $session->sign('sha256-hmac', $key, $data);
 
@@ -60,6 +60,8 @@ This is an identifier that refers to resource inside the HSM, it has no meaning
 
 This is a mechanism for a cryptographic operation, e.g. C<'aes-gcm'>, C<'sha256-rsa-pkcs'> or C<'sha512-hmac'>. The list of supported mechanisms can be retrieved using the C<mechanisms> method on the C<Crypt::HSM> object.
 
+Cryptographic methods taking taking an argument will also take zero or more mechanism specific arguments after their generic arguments, for example an IV for a symmetric cipher.
+
 =item attributes
 
 This is an hash of attributes. The key is the name of the attribute (e.g. C<'class'>, C<'sensitive'>), the value depends on the key but is usually either an integer, a string or a bool.
@@ -76,11 +78,11 @@ Copy an object, optionally adding/modifying the given attributes.
 
 Create an object with the given C<$attribute> hash.
 
-=head2 decrypt($mechanism, $key, $ciphertext)
+=head2 decrypt($mechanism, $key, $ciphertext, ...)
 
 Decrypt C<$ciphertext> with C<$mechanism> and C<$key>.
 
-=head2 derive_key($mechanism, $key, $attributes)
+=head2 derive_key($mechanism, $key, $attributes, ...)
 
 Derive a new key from C<$key>, using mechanism and setting C<$attributes> on it.
 
@@ -88,11 +90,11 @@ Derive a new key from C<$key>, using mechanism and setting C<$attributes> on it.
 
 This deletes the object with the identifier C<$object>
 
-=head2 digest($mechanism, $key, $input)
+=head2 digest($mechanism, $key, $input, ...)
 
 Digest C<$input> with C<$mechanism> and C<$key>.
 
-=head2 encrypt($mechanism, $key, $plaintext)
+=head2 encrypt($mechanism, $key, $plaintext, ...)
 
 Encrypt C<$plaintext> with C<$mechanism> and C<$key>.
 
@@ -100,7 +102,7 @@ Encrypt C<$plaintext> with C<$mechanism> and C<$key>.
 
 Find all objects that satisfy the given C<$attributes>
 
-=head2 generate_key($mechanism, $attributes)
+=head2 generate_key($mechanism, $attributes, ...)
 
 Generate a new key for C<$mechanism> with C<$attributes>. Some relevant attributes are:
 
@@ -142,7 +144,7 @@ This sets the length of a key, this can be useful when creating a C<'generic-sec
 
 Most of these have implementation-specific defaults.
 
-=head2 generate_keypair($mechanism, $public_attributes, $private_attributes)
+=head2 generate_keypair($mechanism, $public_attributes, $private_attributes, ...)
 
 This generates a key pair. The attributes for the 
 
@@ -186,19 +188,19 @@ This sets the C<$attributes> on C<$object>.
 
 This changes the PIN from C<$old_pin> to C<$new_pin>.
 
-=head2 sign($mechanism, $key, $input)
+=head2 sign($mechanism, $key, $input, ...)
 
 This creates a signature over C<$input> using C<$mechanism> and C<$key>.
 
-=head2 unwrap_key($mechanism, $unwrap_key, $wrapped_key, $attributes)
+=head2 unwrap_key($mechanism, $unwrap_key, $wrapped_key, $attributes, ...)
 
 This unwraps the key wrapped in the bytearray C<$wrapped_key> using C<mechanism> and C<$unwrap_key>, setting C<$attributes> on the new key.
 
-=head2 verify($mechanism, $key, $data, $signature)
+=head2 verify($mechanism, $key, $data, $signature, ...)
 
 Verify that C<$signature> matches C<$data>, using C<$mechanism> and C<$key>.
 
-=head2 wrap_key($mechanism, $wrap_key, $key)
+=head2 wrap_key($mechanism, $wrap_key, $key, ...)
 
 This wraps C<$key> using C<$mechanism> and C<$wrap_key>.
 
